Learn R Programming

matie (version 1.0)

matie-package: Measuring Association and Testing Independence Efficiently

Description

Uses a maximum likelihood density ratio to estimate association between pairs of variables from a data set.

Arguments

docType

package

concept

maximum likelihood

Details

ll{ Package: matie Type: Package Version: 1.0 Date: 2013-01-17 License: GPL-3 }

References

coming soon

Examples

Run this code
d <- sbd(NULL,n=400,Rsq=0.9)
    aScore <- ma(d)
    pValue <- ma.test(d,aScore)

Run the code above in your browser using DataLab