Learn R Programming

matie (version 1.0)

rwt: Rank With Ties

Description

This function replaces variable values in a data set with their ranks, using a random tie breaking strategy. It is called by ma and pd.

Arguments